
# [My Moodle Client](https://pypi.org/project/my-moodle-client/ "My Moodle Client")

A Python package to store your data from Moodle.

## Sample Usage

```python
```

---

Copyright &copy; 2024 Mark Crowe <https://github.com/marcocrowe>. All rights reserved.
